import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk_card_horizontal_model.dart';
import 'package:vgkprogaming/theme/vgk_shared_theme.dart';
import 'package:vgkprogaming/widget/vgk_card_horizontal_widget/vgk_card_horizontal_content_widget.dart';

class VgkCardHorizontalWidget extends StatefulWidget {
  const VgkCardHorizontalWidget({
    Key? key,
    required this.mainScreenAnimationController,
    required this.mainScreenAnimation,
    required this.data,
    required this.primaryColor,
  }) : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<double> mainScreenAnimation;
  final List<VgkCardHorizontalDetailModel> data;
  final String primaryColor;
  @override
  _VgkCardHorizontalWidgetState createState() =>
      _VgkCardHorizontalWidgetState();
}

class _VgkCardHorizontalWidgetState extends State<VgkCardHorizontalWidget>
    with TickerProviderStateMixin {
  late AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (context, child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform: VgkProGamingTheme.transform(widget.mainScreenAnimation),
            child: SizedBox(
              height: 150,
              width: double.infinity,
              child: ListView.builder(
                padding: VgkProGamingTheme.edgeInsetsPaddingSmall,
                itemCount: widget.data.length,
                scrollDirection: Axis.horizontal,
                itemBuilder: (BuildContext context, int index) {
                  final Animation<double> animation =
                      VgkProGamingTheme.animationOption(animationController);
                  animationController.forward();
                  return VgkCardHorizontalContentWidget(
                    data: widget.data[index],
                    animationController: animationController,
                    animation: animation,
                    primaryColor: widget.primaryColor,
                  );
                },
              ),
            ),
          ),
        );
      },
    );
  }
}
