import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk_card_horizontal_with_sub_model.dart';
import 'package:vgkprogaming/theme/vgk_shared_theme.dart';
import 'package:vgkprogaming/widget/vgk_sub_title_widget/vgk_sub_title_widget_with_animation.dart';

class VgkCardHorizontalWithSubContentWidget extends StatelessWidget {
  const VgkCardHorizontalWithSubContentWidget({
    Key? key,
    required this.data,
    required this.animationController,
    required this.animation,
    required this.callBack,
    required this.primaryColor,
  }) : super(key: key);

  final VgkCardHorizontaWithSubDetailModel data;
  final AnimationController animationController;
  final Animation<double> animation;
  final String primaryColor;
  final Function(VgkCardHorizontaWithSubDetailModel data) callBack;

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (context, child) {
        return FadeTransition(
          opacity: animation,
          child: Transform(
            transform: VgkProGamingTheme.subTransform(animation),
            child: InkWell(
              splashColor: Colors.transparent,
              child: SizedBox(
                width: 280,
                child: Stack(
                  children: <Widget>[
                    Row(
                      children: <Widget>[
                        const SizedBox(
                          width: 48,
                        ),
                        Expanded(
                          child: Container(
                            decoration: BoxDecoration(
                              color:
                                  VgkProGamingTheme.lightGreyWithOpacityMedium,
                              borderRadius:
                                  VgkProGamingTheme.borderRadiusMedium,
                            ),
                            child: Row(
                              children: <Widget>[
                                const SizedBox(
                                  width: 48 + 24.0,
                                ),
                                Expanded(
                                  child: Column(
                                    children: <Widget>[
                                      Padding(
                                        padding: const EdgeInsets.only(top: 16),
                                        child: VgkSubTitleWithAnimationWidget(
                                          titleTxt: data.key,
                                          animation:
                                              VgkProGamingTheme.animationOption(
                                                  animationController),
                                          animationController:
                                              animationController,
                                          primaryColor: primaryColor,
                                        ),
                                      ),
                                      const Expanded(
                                        child: SizedBox(),
                                      ),
                                      Padding(
                                        padding: const EdgeInsets.only(
                                            right: 16, bottom: 8),
                                        child: Row(
                                          mainAxisAlignment:
                                              MainAxisAlignment.spaceBetween,
                                          crossAxisAlignment:
                                              CrossAxisAlignment.center,
                                          children: <Widget>[
                                            Expanded(
                                              child: Text(
                                                "",
                                                textAlign: TextAlign.left,
                                                style: VgkProGamingTheme.h4(
                                                    primaryColor),
                                              ),
                                            )
                                          ],
                                        ),
                                      ),
                                      Padding(
                                        padding: const EdgeInsets.only(
                                            bottom: 16, right: 16),
                                        child: Row(
                                          mainAxisAlignment:
                                              MainAxisAlignment.spaceBetween,
                                          crossAxisAlignment:
                                              CrossAxisAlignment.start,
                                          children: <Widget>[
                                            Text(
                                              data.value,
                                              textAlign: TextAlign.left,
                                              style: MediaQuery.of(context)
                                                          .size
                                                          .width >=
                                                      375
                                                  ? VgkProGamingTheme.h2(
                                                      primaryColor)
                                                  : VgkProGamingTheme.h3(
                                                      primaryColor),
                                            ),
                                            Container(
                                              decoration: BoxDecoration(
                                                color: HexColor(primaryColor),
                                                borderRadius:
                                                    const BorderRadius.all(
                                                        Radius.circular(8.0)),
                                              ),
                                              child: Padding(
                                                padding:
                                                    const EdgeInsets.all(5),
                                                child: Text(
                                                  'more',
                                                  style:
                                                      VgkProGamingTheme.h3White,
                                                ),
                                              ),
                                            )
                                          ],
                                        ),
                                      ),
                                    ],
                                  ),
                                ),
                              ],
                            ),
                          ),
                        )
                      ],
                    ),
                    Padding(
                      padding:
                          const EdgeInsets.only(top: 24, bottom: 24, left: 16),
                      child: Row(
                        children: <Widget>[
                          ClipRRect(
                            borderRadius:
                                const BorderRadius.all(Radius.circular(16.0)),
                            child: Container(
                              padding: const EdgeInsets.only(
                                  top: 16, bottom: 16, right: 16, left: 16),
                              color: VgkProGamingTheme.grey.withOpacity(0.2),
                              child: AspectRatio(
                                aspectRatio: 1.0,
                                child: CachedNetworkImage(
                                  imageUrl: data.src,
                                  progressIndicatorBuilder:
                                      (context, url, downloadProgress) =>
                                          CircularProgressIndicator(
                                              value: downloadProgress.progress),
                                  errorWidget: (context, url, error) =>
                                      const Icon(Icons.error),
                                ),
                                // child: Image.network(data.src),
                              ),
                            ),
                          ),
                        ],
                      ),
                    ),
                  ],
                ),
              ),
              onTap: () {
                Navigator.push<dynamic>(
                  context,
                  MaterialPageRoute<dynamic>(
                    builder: (BuildContext context) => callBack(data),
                  ),
                );
              },
            ),
          ),
        );
      },
    );
  }
}
