import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk_card_horizontal_with_sub_model.dart';
import 'package:vgkprogaming/theme/vgk_shared_theme.dart';
import 'package:vgkprogaming/widget/vgk_card_horizontal_with_sub_widget/vgk_card_horizontal_with_sub_content_widget.dart';

class VgkCardHorizontaWithSubWidget extends StatefulWidget {
  const VgkCardHorizontaWithSubWidget({
    Key? key,
    required this.mainScreenAnimationController,
    required this.mainScreenAnimation,
    required this.data,
    required this.callBack,
    required this.primaryColor,
  }) : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<double> mainScreenAnimation;
  final List<VgkCardHorizontaWithSubDetailModel> data;
  final Function(VgkCardHorizontaWithSubDetailModel data) callBack;
  final String primaryColor;
  @override
  _VgkCardHorizontaWithSubWidgetState createState() =>
      _VgkCardHorizontaWithSubWidgetState();
}

class _VgkCardHorizontaWithSubWidgetState
    extends State<VgkCardHorizontaWithSubWidget> with TickerProviderStateMixin {
  late AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return buildAnimatedBuilder(
      widget.mainScreenAnimationController,
      widget.mainScreenAnimation,
      widget.data,
      animationController,
      (a, b, c) => VgkCardHorizontalWithSubContentWidget(
        data: a,
        animationController: b,
        animation: c as Animation<double>,
        callBack: widget.callBack,
        primaryColor: widget.primaryColor,
      ),
    );
  }

  static Widget buildAnimatedBuilder(
    AnimationController mainScreenAnimationController,
    Animation<double> mainScreenAnimation,
    List<VgkCardHorizontaWithSubDetailModel> data,
    AnimationController animationController,
    Function(VgkCardHorizontaWithSubDetailModel data, AnimationController b,
            Animation<dynamic> c)
        callBack,
  ) {
    return AnimatedBuilder(
      animation: mainScreenAnimationController,
      builder: (context, child) {
        return FadeTransition(
          opacity: mainScreenAnimation,
          child: Transform(
            transform: VgkProGamingTheme.transform(mainScreenAnimation),
            child: SizedBox(
              height: 150,
              width: double.infinity,
              child: ListView.builder(
                padding: VgkProGamingTheme.edgeInsetsPaddingTripleExtraLarge,
                itemCount: data.length,
                scrollDirection: Axis.horizontal,
                itemBuilder: (BuildContext context, int index) {
                  final Animation<double> animation =
                      VgkProGamingTheme.animationOption(animationController);
                  animationController.forward();
                  return callBack(
                    data[index],
                    animationController,
                    animation,
                  );
                },
              ),
            ),
          ),
        );
      },
    );
  }
}
