import 'dart:async';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk_card_image_widget_model.dart';
import 'package:vgkprogaming/theme/vgk_shared_theme.dart';

class VgkCardImageWidget extends StatefulWidget {
  const VgkCardImageWidget(
      {Key? key,
      required this.mainScreenAnimationController,
      required this.mainScreenAnimation,
      required this.data})
      : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<double> mainScreenAnimation;
  final VgkCardImageWidgetModel data;
  @override
  _VgkCardImageWidgetState createState() => _VgkCardImageWidgetState();
}

class _VgkCardImageWidgetState extends State<VgkCardImageWidget>
    with TickerProviderStateMixin {
  late AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  Future<bool> getData() async {
    await Future<dynamic>.delayed(const Duration(milliseconds: 50));
    return true;
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (context, child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform:
                VgkProGamingTheme.subTransform(widget.mainScreenAnimation),
            child: Container(
              padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
              child: ClipRRect(
                borderRadius: const BorderRadius.all(Radius.circular(16.0)),
                child: Stack(
                  children: <Widget>[
                    Column(
                      children: <Widget>[
                        AspectRatio(
                          aspectRatio: 2,
                          child: CachedNetworkImage(
                            imageUrl: widget.data.src,
                            fit: BoxFit.fill,
                            progressIndicatorBuilder:
                                (context, url, downloadProgress) =>
                                    CircularProgressIndicator(
                                        value: downloadProgress.progress),
                            errorWidget: (context, url, error) =>
                                const Icon(Icons.error),
                          ),
                        ),
                      ],
                    )
                  ],
                ),
              ),
            ),
          ),
        );
      },
    );
  }
}
