import 'dart:async';
import 'package:clipboard/clipboard.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk_card_image_with_copy_widget_model.dart';
import 'package:vgkprogaming/theme/vgk_shared_theme.dart';
import 'package:vgkprogaming/utils/vgk_common_utils.dart';

class VgkCardImageWithCopyWidget extends StatefulWidget {
  const VgkCardImageWithCopyWidget(
      {Key? key,
      required this.mainScreenAnimationController,
      required this.mainScreenAnimation,
      required this.data,
      required this.primaryColor})
      : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<double> mainScreenAnimation;
  final VgkCardImageWithCopyWidgetModel data;
  final String primaryColor;
  @override
  _VgkCardImageWithCopyWidgetState createState() =>
      _VgkCardImageWithCopyWidgetState();
}

class _VgkCardImageWithCopyWidgetState extends State<VgkCardImageWithCopyWidget>
    with TickerProviderStateMixin {
  late AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  Future<bool> getData() async {
    await Future<dynamic>.delayed(const Duration(milliseconds: 50));
    return true;
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (context, child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform:
                VgkProGamingTheme.subTransform(widget.mainScreenAnimation),
            child: Container(
              child: Card(
                child: Padding(
                  padding: const EdgeInsets.fromLTRB(12, 0, 12, 12),
                  child: Column(
                    children: [
                      Row(
                        children: <Widget>[
                          Padding(
                            padding: const EdgeInsets.fromLTRB(0, 6, 0, 6),
                            child: Text(
                              widget.data.key,
                              textAlign: TextAlign.left,
                              style: VgkProGamingTheme.h1(widget.primaryColor),
                            ),
                          ),
                          const Spacer(),
                          ButtonBar(
                            children: <Widget>[
                              Visibility(
                                visible:
                                    (widget.data.bgmi == "") ? false : true,
                                child: InkWell(
                                  onTap: () {
                                    FlutterClipboard.copy(widget.data.bgmi);
                                    const snackBar = SnackBar(
                                      content: Text("BGMI Share Code Copied"),
                                    );
                                    ScaffoldMessenger.of(context)
                                        .showSnackBar(snackBar);
                                  },
                                  child: Row(
                                    mainAxisSize: MainAxisSize.min,
                                    children: <Widget>[
                                      IconButton(
                                        icon: Icon(
                                          Icons.copy,
                                          size: 18,
                                          color: HexColor(widget.primaryColor),
                                        ),
                                        onPressed: () {},
                                      ),
                                      const Text("bgmi code"),
                                    ],
                                  ),
                                ),
                              ),
                              Visibility(
                                visible:
                                    (widget.data.global == "") ? false : true,
                                child: InkWell(
                                  onTap: () {
                                    FlutterClipboard.copy(
                                      widget.data.global,
                                    );
                                    const snackBar = SnackBar(
                                      content: Text("Global Share Code Copied"),
                                    );
                                    ScaffoldMessenger.of(context)
                                        .showSnackBar(snackBar);
                                  },
                                  child: Row(
                                    mainAxisSize: MainAxisSize.min,
                                    children: <Widget>[
                                      IconButton(
                                        icon: Icon(
                                          Icons.copy,
                                          size: 18,
                                          color: HexColor(widget.primaryColor),
                                        ),
                                        onPressed: () {},
                                      ),
                                      const Text("global code"),
                                    ],
                                  ),
                                ),
                              )
                            ],
                          )
                        ],
                      ),
                      AspectRatio(
                        aspectRatio: 2,
                        child: VgkCommonUtils.imageloader(widget.data.src),
                      ),
                    ],
                  ),
                ),
              ),
              decoration: BoxDecoration(
                boxShadow: [
                  BoxShadow(
                    color: Colors.grey.shade500,
                    blurRadius: 20.0,
                  ),
                ],
              ),
            ),
          ),
        );
      },
    );
  }
}
