import 'package:cached_network_image/cached_network_image.dart';
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk_card_horizontal_with_sub_model.dart';
import 'package:vgkprogaming/theme/vgk_shared_theme.dart';

class VgkBestAttachmentSetList extends StatefulWidget {
  const VgkBestAttachmentSetList({
    Key? key,
    required this.mainScreenAnimationController,
    required this.mainScreenAnimation,
    required this.data,
    required this.width,
    required this.height,
    required this.primaryColor,
  }) : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<double> mainScreenAnimation;
  final double width;
  final double height;
  final String primaryColor;
  final List<VgkAttachementModel> data;
  @override
  _VgkBestAttachmentSetListState createState() =>
      _VgkBestAttachmentSetListState();
}

class _VgkBestAttachmentSetListState extends State<VgkBestAttachmentSetList>
    with TickerProviderStateMixin {
  late AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  Future<bool> getData() async {
    await Future<dynamic>.delayed(const Duration(milliseconds: 50));
    return true;
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (context, child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform: VgkProGamingTheme.transform(widget.mainScreenAnimation),
            child: SizedBox(
              height: widget.height,
              width: double.infinity,
              child: ListView.builder(
                padding: const EdgeInsets.only(
                    top: 0, bottom: 0, right: 16, left: 16),
                itemCount: widget.data.length,
                scrollDirection: Axis.horizontal,
                itemBuilder: (BuildContext context, int index) {
                  final animation =
                      VgkProGamingTheme.animationOption(animationController);
                  animationController.forward();
                  return BestAttachmentSet(
                    data: widget.data[index],
                    animation: animation,
                    animationController: animationController,
                    width: widget.width,
                    primaryColor: widget.primaryColor,
                  );
                },
              ),
            ),
          ),
        );
      },
    );
  }
}

class BestAttachmentSet extends StatelessWidget {
  const BestAttachmentSet(
      {Key? key,
      required this.data,
      required this.animationController,
      required this.animation,
      required this.width,
      required this.primaryColor})
      : super(key: key);

  final double width;
  final VgkAttachementModel data;
  final AnimationController animationController;
  final Animation<double> animation;
  final String primaryColor;
  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (context, child) {
        return FadeTransition(
          opacity: animation,
          child: Transform(
            transform: VgkProGamingTheme.transform(animation),
            child: SizedBox(
              width: width,
              child: Stack(
                children: <Widget>[
                  Padding(
                    padding:
                        const EdgeInsets.only(top: 16, right: 8, bottom: 16),
                    child: Container(
                      width: width,
                      decoration: VgkProGamingTheme.cardDecorationWithPopUp(
                          primaryColor),
                      child: Padding(
                        padding: const EdgeInsets.only(
                            top: 54, left: 16, right: 16, bottom: 8),
                        child: Column(
                          mainAxisAlignment: MainAxisAlignment.center,
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: <Widget>[
                            Text(
                              data.key.toLowerCase(),
                              textAlign: TextAlign.center,
                              style: VgkProGamingTheme.h1White,
                            ),
                            const SizedBox(
                              height: 8,
                            ),
                            Text(
                              data.value.toLowerCase(),
                              textAlign: TextAlign.center,
                              style: VgkProGamingTheme.h3White,
                            ),
                          ],
                        ),
                      ),
                    ),
                  ),
                  Positioned(
                    top: 0,
                    left: 0,
                    child: Container(
                      width: 84,
                      height: 84,
                      decoration: BoxDecoration(
                        color: VgkProGamingTheme.nearlyWhite.withOpacity(0.2),
                        shape: BoxShape.circle,
                      ),
                    ),
                  ),
                  Positioned(
                    top: 20,
                    left: 20,
                    child: SizedBox(
                      width: 50,
                      height: 50,
                      child: CachedNetworkImage(
                        imageUrl: data.src,
                        progressIndicatorBuilder:
                            (context, url, downloadProgress) =>
                                CircularProgressIndicator(
                                    value: downloadProgress.progress),
                        errorWidget: (context, url, error) =>
                            const Icon(Icons.error),
                      ),
                    ),
                  )
                ],
              ),
            ),
          ),
        );
      },
    );
  }
}
