import 'package:flutter/material.dart';
import 'dart:ui' as ui;
import 'dart:async';
import 'dart:math';
import 'dart:typed_data';
import 'package:flutter/services.dart' show rootBundle;
import 'package:vgkprogaming/model/vgk_damage_model.dart';
import 'package:vgkprogaming/theme/vgk_shared_theme.dart';

class VgkHitToKillCanvasWidget extends StatefulWidget {
  const VgkHitToKillCanvasWidget({
    Key? key,
    required this.mainScreenAnimationController,
    required this.mainScreenAnimation,
    required this.data,
    required this.primaryColor,
  }) : super(key: key);

  final AnimationController mainScreenAnimationController;
  final VgkDamageDetailsModel data;
  final Animation<double> mainScreenAnimation;
  final String primaryColor;
  @override
  _VgkHitToKillCanvasWidgetState createState() =>
      _VgkHitToKillCanvasWidgetState();
}

class _VgkHitToKillCanvasWidgetState extends State<VgkHitToKillCanvasWidget>
    with TickerProviderStateMixin {
  late ui.Image _originalImage;
  late ui.Image _displayImage;
  final double increment = pi / 18;
  final String imagePath = 'assets/images/body.png';
  late AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    loadImage(imagePath);
    super.initState();
  }

  Future<bool> getData() async {
    await Future<dynamic>.delayed(const Duration(milliseconds: 50));
    return true;
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (context, child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform: VgkProGamingTheme.transform(widget.mainScreenAnimation),
            child: getTextAlignment(),
          ),
        );
      },
    );
  }

  Widget getTextAlignment() {
    var screenSize = MediaQuery.of(context).size;
    final scale = (screenSize.width - 150) / _originalImage.width;
    return Padding(
      padding: VgkProGamingTheme.edgeInsetsPaddingLarge,
      child: Container(
        decoration: VgkProGamingTheme.decoration,
        child: Row(
          children: <Widget>[
            VgkProGamingTheme.sizedBoxEmpty,
            Expanded(
              child: Column(
                children: <Widget>[
                  SizedBox(
                    child: CustomPaint(
                      painter: MyPainter(
                          image: _displayImage,
                          scale: scale,
                          selectedDamageDetails: widget.data,
                          primaryColor: widget.primaryColor),
                      size: Size(
                        _displayImage.width * scale,
                        _displayImage.height * scale,
                      ),
                    ),
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }

  void loadImage(String filePath) async {
    ui.Image image = await imageFromFilePath(filePath);
    _originalImage = image;
    setState(() {
      _displayImage = image;
    });
  }
}

class MyPainter extends CustomPainter {
  final ui.Image image;
  final double scale;
  final VgkDamageDetailsModel selectedDamageDetails;
  final String primaryColor;
  MyPainter(
      {required this.image,
      required this.scale,
      required this.selectedDamageDetails,
      required this.primaryColor});

  String calculateHitToKill(String input) {
    if (input.contains('/')) {
      var splitedData = input.split('/');
      double calculatedValue =
          int.parse(splitedData[0]) / int.parse(splitedData[1]);
      return calculatedValue.toStringAsFixed(0);
    } else {
      return input;
    }
  }

  ratioCalculation(double input) {
    return (input - 52).toDouble();
  }

  @override
  void paint(Canvas canvas, Size size) async {
    canvas.scale(scale);
    canvas.drawImage(image, Offset.zero, Paint());
    appendTextIntoCanvas(canvas, ratioCalculation(130), 10, size,
        calculateHitToKill(selectedDamageDetails.head), primaryColor);
    appendTextIntoCanvas(canvas, ratioCalculation(130), 40, size,
        calculateHitToKill(selectedDamageDetails.neck), primaryColor);
    appendTextIntoCanvas(canvas, ratioCalculation(130), 55, size,
        calculateHitToKill(selectedDamageDetails.clavicles), primaryColor);
    appendTextIntoCanvas(canvas, ratioCalculation(130), 90, size,
        calculateHitToKill(selectedDamageDetails.upperChest), primaryColor);
    appendTextIntoCanvas(canvas, ratioCalculation(130), 135, size,
        calculateHitToKill(selectedDamageDetails.lowerChest), primaryColor);
    appendTextIntoCanvas(canvas, ratioCalculation(130), 165, size,
        calculateHitToKill(selectedDamageDetails.stomach), primaryColor);
    appendTextIntoCanvas(canvas, ratioCalculation(130), 190, size,
        calculateHitToKill(selectedDamageDetails.pelvis), primaryColor);
    appendTextIntoCanvas(canvas, 100, 240, size,
        calculateHitToKill(selectedDamageDetails.upperLimb), primaryColor);
    appendTextIntoCanvas(canvas, 110, 330, size,
        calculateHitToKill(selectedDamageDetails.lowerLimb), primaryColor);
    appendTextIntoCanvas(canvas, 115, 380, size,
        calculateHitToKill(selectedDamageDetails.handFoot), primaryColor);
    appendTextIntoCanvas(canvas, 118, 110, size,
        calculateHitToKill(selectedDamageDetails.upperLimb), primaryColor);
    appendTextIntoCanvas(canvas, 125, 175, size,
        calculateHitToKill(selectedDamageDetails.lowerLimb), primaryColor);
    appendTextIntoCanvas(canvas, 135, 215, size,
        calculateHitToKill(selectedDamageDetails.handFoot), primaryColor);

    appendTextIntoCanvas(canvas, 32, 110, size,
        calculateHitToKill(selectedDamageDetails.upperLimb), primaryColor);
    appendTextIntoCanvas(canvas, 20, 175, size,
        calculateHitToKill(selectedDamageDetails.lowerLimb), primaryColor);
    appendTextIntoCanvas(canvas, 10, 215, size,
        calculateHitToKill(selectedDamageDetails.handFoot), primaryColor);

    appendTextIntoCanvas(canvas, 50, 240, size,
        calculateHitToKill(selectedDamageDetails.upperLimb), primaryColor);
    appendTextIntoCanvas(canvas, 40, 330, size,
        calculateHitToKill(selectedDamageDetails.lowerLimb), primaryColor);
    appendTextIntoCanvas(canvas, 35, 380, size,
        calculateHitToKill(selectedDamageDetails.handFoot), primaryColor);
  }

  @override
  bool shouldRepaint(covariant CustomPainter oldDelegate) {
    return true;
  }
}

Future<ui.Image> imageFromFilePath(String filePath) async {
  var byteData = await rootBundle.load(filePath);
  Uint8List lst = Uint8List.view(byteData.buffer);
  var codec = await ui.instantiateImageCodec(lst);
  var nextFrame = await codec.getNextFrame();
  return nextFrame.image;
}

appendTextIntoCanvas(Canvas canvas, double x, double y, Size size, String text,
    String primaryColor) {
  final textPainter = TextPainter(
    text: TextSpan(
      text: text,
      style: VgkProGamingTheme.h2(primaryColor),
    ),
    textDirection: TextDirection.ltr,
  );
  textPainter.layout(
    minWidth: 0,
    maxWidth: size.width,
  );
  final offset = Offset(x, y);
  textPainter.paint(canvas, offset);
}
