import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk_card_horizontal_with_sub_model.dart';
import 'package:vgkprogaming/theme/vgk_shared_theme.dart';
import 'package:vgkprogaming/widget/vgk_common_widget/vgk_common_widget.dart';

class VgkRangeDetails extends StatelessWidget {
  final AnimationController animationController;
  final Animation<double> animation;
  final VgkCardHorizontaWithSubDetailModel data;
  final int divider;
  final String primaryColor;
  const VgkRangeDetails(
      {Key? key,
      required this.animationController,
      required this.animation,
      required this.data,
      required this.divider,
      required this.primaryColor})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (context, child) {
        return FadeTransition(
          opacity: animation,
          child: Transform(
            transform: VgkProGamingTheme.transform(animation),
            child: Padding(
              padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraSmall,
              child: Container(
                decoration: BoxDecoration(
                  color: VgkProGamingTheme.boxBackground.withOpacity(0.6),
                  borderRadius: const BorderRadius.all(Radius.circular(16.0)),
                ),
                child: Column(
                  children:
                      generateInfoDetails(data, context, divider, primaryColor),
                ),
              ),
            ),
          ),
        );
      },
    );
  }

  rangeInfo(List<VgkHeadModel> range, primaryColor) {
    var result = <Widget>[];
    for (var element in range) {
      result.add(
        VgkCommonWidget.vgkRangeInfo(
            element.key,
            VgkProGamingTheme.intToStringConvertor(element.value),
            VgkProGamingTheme.stringToIntConvertor('100'),
            primaryColor),
      );
      result.add(const SizedBox(
        height: 3,
      ));
    }
    return result;
  }

  generateInfoDetails(VgkCardHorizontaWithSubDetailModel data, context,
      int divider, primaryColor) {
    var result = <Widget>[];
    result.add(Padding(
      padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
      child: Row(
        children: <Widget>[
          Expanded(
            child: Text(
              data.key.toUpperCase(),
              textAlign: TextAlign.left,
              style: MediaQuery.of(context).size.width >= 375
                  ? VgkProGamingTheme.h2(primaryColor)
                  : VgkProGamingTheme.h3(primaryColor),
            ),
          ),
        ],
      ),
    ));
    result.add(
      Padding(
        padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
        child: Row(
          children: <Widget>[
            Expanded(
              child: Padding(
                padding: const EdgeInsets.only(
                  right: VgkProGamingTheme.paddingDoubleExtraLarge,
                ),
                child: Column(children: rangeInfo(data.range, primaryColor)),
              ),
            ),
            Center(
              child: Stack(
                children: <Widget>[
                  Container(
                    width: 100,
                    height: 120,
                    decoration: BoxDecoration(
                      color: VgkProGamingTheme.grey.withOpacity(0.1),
                      borderRadius: const BorderRadius.all(
                        Radius.circular(16.0),
                      ),
                    ),
                    child: Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.center,
                      children: <Widget>[
                        Padding(
                          padding: const EdgeInsets.all(8.0),
                          child: CachedNetworkImage(
                            imageUrl: data.src,
                            progressIndicatorBuilder:
                                (context, url, downloadProgress) =>
                                    CircularProgressIndicator(
                                        value: downloadProgress.progress),
                            errorWidget: (context, url, error) =>
                                const Icon(Icons.error),
                          ),
                          // child: Image.network(data.src),
                        ),
                      ],
                    ),
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
    result.add(
      Padding(
        padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
        child: Container(
          height: 2,
          decoration: BoxDecoration(
            color: VgkProGamingTheme.background,
            borderRadius: const BorderRadius.all(Radius.circular(4.0)),
          ),
        ),
      ),
    );
    if (divider == 1 && data.info.isNotEmpty) {
      for (var element in data.info) {
        result.add(
          VgkCommonWidget.vgkRangeInfo(
              element.key, element.value, 100, primaryColor),
        );
      }
    }
    if (divider == 2 && data.info.isNotEmpty) {
      int index = (data.info.length ~/ divider).toInt();
      if (data.info.length == 1) {
        index = 1;
      }
      int currentData = 0;
      for (var i = 0; i < index; i++) {
        var firstElement = data.info[currentData];
        VgkHeadModel? secondElement;
        if (currentData + 1 < data.info.length) {
          secondElement = data.info[currentData + 1];
        }
        currentData = currentData + 2;
        result.add(
          widgetForDamageDetails(
              firstElement.key,
              firstElement.value,
              secondElement != null ? secondElement.key : "",
              secondElement != null ? secondElement.value : "",
              primaryColor),
        );
      }
    }
    return result;
  }
}

Widget widgetForDamageDetails(firstColumnTitle, firstColumnValue,
    secondColumnTitle, secondColumnValue, primaryColor) {
  return Padding(
    padding: const EdgeInsets.only(
      left: VgkProGamingTheme.paddingDoubleExtraLarge,
      right: VgkProGamingTheme.paddingDoubleExtraLarge,
      top: VgkProGamingTheme.paddingDoubleExtraSmall,
      bottom: VgkProGamingTheme.paddingDoubleExtraSmall,
    ),
    child: Row(
      children: <Widget>[
        Expanded(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Text(
                    firstColumnTitle,
                    textAlign: TextAlign.center,
                    style: VgkProGamingTheme.h2(primaryColor),
                  ),
                  Padding(
                    padding: const EdgeInsets.only(top: 6),
                    child: Text(
                      firstColumnValue,
                      textAlign: TextAlign.center,
                      style: VgkProGamingTheme.h3WithOpacity(primaryColor),
                    ),
                  ),
                ],
              ),
            ],
          ),
        ),
        Expanded(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Text(
                    secondColumnTitle,
                    style: VgkProGamingTheme.h2(primaryColor),
                  ),
                  Padding(
                    padding: const EdgeInsets.only(top: 6),
                    child: Text(
                      secondColumnValue,
                      textAlign: TextAlign.center,
                      style: VgkProGamingTheme.h3WithOpacity(primaryColor),
                    ),
                  ),
                ],
              ),
            ],
          ),
        )
      ],
    ),
  );
}
