import 'package:cached_network_image/cached_network_image.dart';
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk_short_to_kill_list_model.dart';
import 'package:vgkprogaming/theme/vgk_shared_theme.dart';

class VgkShotsToKillListWidget extends StatefulWidget {
  const VgkShotsToKillListWidget({
    Key? key,
    required this.title,
    required this.mainScreenAnimationController,
    required this.mainScreenAnimation,
    required this.data,
    required this.primaryColor,
  }) : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<double> mainScreenAnimation;
  final List<VgkShortToKillListModel> data;
  final String title;
  final String primaryColor;
  @override
  _VgkShotsToKillListWidgetState createState() =>
      _VgkShotsToKillListWidgetState();
}

class _VgkShotsToKillListWidgetState extends State<VgkShotsToKillListWidget>
    with TickerProviderStateMixin {
  late AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  Future<bool> getData() async {
    await Future<dynamic>.delayed(const Duration(milliseconds: 50));
    return true;
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (context, child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform: VgkProGamingTheme.transform(widget.mainScreenAnimation),
            child: SizedBox(
              height: 300,
              width: double.infinity,
              child: ListView.builder(
                itemCount: widget.data.length,
                scrollDirection: Axis.horizontal,
                itemBuilder: (BuildContext context, int index) {
                  final Animation<double> animation =
                      VgkProGamingTheme.animationOption(animationController);
                  animationController.forward();
                  return ShotsToKill(
                    title: widget.title,
                    data: widget.data[index],
                    animation: animation,
                    animationController: animationController,
                    primaryColor: widget.primaryColor,
                  );
                },
              ),
            ),
          ),
        );
      },
    );
  }
}

SingleChildScrollView loadShotToKillAnalysisDetails(
    String title, List<VgkShortToKillModel> data) {
  return SingleChildScrollView(
    scrollDirection: Axis.vertical,
    child: DataTable(
      columns: [
        DataColumn(
          label: Center(
            child: Text(
              title + ' Level         ',
              textAlign: TextAlign.right,
              style: VgkProGamingTheme.h3White,
            ),
          ),
        ),
        DataColumn(
          label: Center(
            child: Text(
              'Shots to kill                     ',
              textAlign: TextAlign.center,
              style: VgkProGamingTheme.h3White,
            ),
          ),
        ),
      ],
      rows: data
          .map(
            ((element) => DataRow(cells: <DataCell>[
                  DataCell(
                    dataWithIcon(element.name, element.src),
                  ),
                  DataCell(
                    Center(
                      child: Text(
                        element.value,
                        textAlign: TextAlign.center,
                        style: VgkProGamingTheme.h3White,
                      ),
                    ),
                  ),
                ])),
          )
          .toList(),
    ),
  );
}

getImage(url) {
  if (url != "") {
    return SizedBox(
      width: 30,
      height: 30,
      child: CachedNetworkImage(
        imageUrl: url,
        progressIndicatorBuilder: (context, url, downloadProgress) =>
            CircularProgressIndicator(value: downloadProgress.progress),
        errorWidget: (context, url, error) => const Icon(Icons.error),
      ),
    );
  } else {
    return const Icon(Icons.do_not_disturb, color: Color(0xffffffff));
  }
}

ListTile dataWithIcon(String name, String url) {
  return ListTile(
    leading: getImage(url),
    title: Text(
      name,
      style: VgkProGamingTheme.h3White,
    ),
  );
}

class ShotsToKill extends StatelessWidget {
  const ShotsToKill(
      {Key? key,
      required this.title,
      required this.data,
      required this.animationController,
      required this.animation,
      required this.primaryColor})
      : super(key: key);

  final VgkShortToKillListModel data;
  final AnimationController animationController;
  final Animation<double> animation;
  final String title;
  final String primaryColor;
  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (context, child) {
        return FadeTransition(
          opacity: animation,
          child: Transform(
            transform: VgkProGamingTheme.transform(animation),
            child: Padding(
              padding: const EdgeInsets.only(left: 12, top: 16, bottom: 16),
              child: Container(
                decoration: BoxDecoration(
                  color: VgkProGamingTheme.boxBackground.withOpacity(0.6),
                  borderRadius: const BorderRadius.all(Radius.circular(16.0)),
                ),
                child: Column(
                  children: <Widget>[
                    Expanded(
                      child: Container(
                        decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(12.0),
                          color: HexColor(primaryColor),
                          gradient: LinearGradient(
                              colors: [
                                HexColor(primaryColor),
                                HexColor(primaryColor).withOpacity(0.6)
                              ],
                              begin: Alignment.centerRight,
                              end: const Alignment(-1.0, -1.0)), //Gradient
                        ),
                        child: loadShotToKillAnalysisDetails(title, data.data),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ),
        );
      },
    );
  }
}
